.. SPDX-FileCopyrightText: 2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: WTFPL
.. No warranty.

gentle.metadata.types
=====================

.. automodule:: gentle.metadata.types
   :members:
